==> rivendell-1.7.0.tar.gz: rivendell-1.7.0/rdairplay/rdairplay_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Audition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>EST TIME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LEN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAirPlay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDAirPlay - Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ADD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COPY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>Operating Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>Next Timed Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-2.8.0.tar.gz: rivendell-2.8.0/rdairplay/rdairplay_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HourSelector</name>
    <message>
        <source>12a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11p</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>EST TIME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LEN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALBUM</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAirPlay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ADD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COPY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>LiveAssist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operating Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>Next Timed Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PAUSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RESUME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WHERE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DELETE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOVE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TO?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COPY?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
